@@ -44,6 +44,7 @@ from hypothesis.internal.conjecture.data import (
     StopTest,
 )
 from hypothesis.internal.conjecture.datatree import DataTree
+from hypothesis.internal.conjecture.junkdrawer import pop_random
 from hypothesis.internal.conjecture.shrinker import Shrinker, sort_key
 from hypothesis.internal.healthcheck import fail_health_check
 from hypothesis.reporting import debug_report
@@ -421,6 +422,7 @@ class ConjectureRunner(object):
             choices = data.block_starts.get(n, [])
             if choices:
                 i = self.random.choice(choices)
+                assert i + n <= len(data.buffer)
                 return hbytes(data.buffer[i : i + n])
             else:
                 result = uniform(self.random, n)
@@ -480,11 +482,13 @@ class ConjectureRunner(object):
             if data.index + n > len(target_data[0].buffer):
                 result = uniform(self.random, n)
             else:
-                result = self.random.choice(bits)(data, n)
+                draw = self.random.choice(bits)
+                result = draw(data, n)
             p = prefix[0]
             if data.index < len(p):
                 start = p[data.index : data.index + n]
                 result = start + result[len(start) :]
+            assert len(result) == n
             return self.__zero_bound(data, result)
 
         return mutate_from
@@ -892,20 +896,6 @@ def uniform(random, n):
     return int_to_bytes(random.getrandbits(n * 8), n)
 
 
-def pop_random(random, values):
-    """Remove a random element of values, possibly changing the ordering of its
-    elements."""
-
-    # We pick the element at a random index. Rather than removing that element
-    # from the list (which would be an O(n) operation), we swap it to the end
-    # and return the last element of the list. This changes the order of
-    # the elements, but as long as these elements are only accessed through
-    # random sampling that doesn't matter.
-    i = random.randrange(0, len(values))
-    values[i], values[-1] = values[-1], values[i]
-    return values.pop()
-
-
 class TargetSelector(object):
     """Data structure for selecting targets to use for mutation.
 
